<?php

namespace EventPortal\AuthPassword\Http\Controllers;

use EventPortal\Http\Controllers\Controller;
use Illuminate\Contracts\Auth\PasswordBroker;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Illuminate\Http\Request;
use Illuminate\Validation\ValidationException;
use Inertia\Inertia;
use Inertia\Response;

class SendPasswordResetEmailController extends Controller
{
    use SendsPasswordResetEmails;

    public function showLinkRequestForm(): Response
    {
        return Inertia::render('ResetPassword/Index');
    }

    /**
     * Get the response for a successful password reset link.
     *
     * @param mixed $response
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\JsonResponse
     */
    protected function sendResetLinkResponse(Request $request, $response)
    {
        if ($request->wantsJson()) {
            return response()->json([
                'message' => trans($response),
            ]);
        }

        return back()->with([
            'successMessage' => trans($response),
        ]);
    }

    /**
     * Get the response for a failed password reset link.
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\JsonResponse
     */
    protected function sendResetLinkFailedResponse(Request $request, string $response)
    {
        // Prevent user enumeration by overriding 'user not found' error
        if ($response === PasswordBroker::INVALID_USER) {
            toast()->neverTimeout()->success(trans('passwords.sent'));

            return back();
        }

        if ($request->wantsJson()) {
            throw ValidationException::withMessages([
                'email' => [trans($response)],
            ]);
        }

        return back()
            ->withInput($request->only('email'))
            ->withErrors(['email' => trans($response)]);
    }
}
